### 1. [Create a developer application on reddit](https://www.reddit.com/prefs/apps)

&nbsp; 

### 2. Click on `create an app`

![PrefsPanel01](https://user-images.githubusercontent.com/55965894/108690386-27288d80-74af-11eb-81a9-a0854ca7304d.png)

&nbsp; 

### 3. Fill information

- must select `script`
- any random information would suffice for `name` and `redirect uri`

&nbsp; 

![AppName02](https://user-images.githubusercontent.com/55965894/108690978-d2394700-74af-11eb-9992-e81f8ba71bd4.png)

&nbsp; 

### 4. Reddit developer acccount information example shown below

&nbsp; 

![reddit_api_app original](https://user-images.githubusercontent.com/55965894/120106481-eaa1a900-c111-11eb-92eb-cefe5d75cc62.png)


### 5. Fill this information in `myreddit-dl/myreddit-dl/config.ini`

`config.ini` example:


```console
[REDDIT]
client_id=udaxhnaso370rmnl
client_secret=wa9fho1nodfafffBFAsolfaQ
username=throwUpvoteDownload
password=throwUpvoteDownload
```


### 6. [Installation can begin](https://github.com/emanuel2718/myredditdl/blob/master/README.md)
